# Generated by roxygen2: do not edit by hand

S3method("$",enrichResult)
S3method("$",gseaResult)
S3method("[",enrichResult)
S3method("[",gseaResult)
S3method("[[",enrichResult)
S3method("[[",gseaResult)
S3method(as.data.frame,enrichResult)
S3method(as.data.frame,gseaResult)
S3method(dim,enrichResult)
S3method(dim,gseaResult)
S3method(geneID,compareClusterResult)
S3method(geneID,enrichResult)
S3method(geneID,gseaResult)
S3method(geneInCategory,compareClusterResult)
S3method(geneInCategory,enrichResult)
S3method(geneInCategory,gseaResult)
S3method(head,enrichResult)
S3method(head,gseaResult)
S3method(tail,enrichResult)
S3method(tail,gseaResult)
export(EXTID2NAME)
export(clusterSim)
export(doSim)
export(doseSim)
export(enrichDGN)
export(enrichDGNv)
export(enrichDO)
export(enrichNCG)
export(facet_grid)
export(gene2DO)
export(geneID)
export(geneInCategory)
export(geneSim)
export(gseDGN)
export(gseDO)
export(gseNCG)
export(gsfilter)
export(mclusterSim)
export(parse_ratio)
export(setReadable)
export(simplot)
export(theme_dose)
exportClasses(compareClusterResult)
exportClasses(enrichResult)
exportClasses(gseaResult)
exportMethods(show)
exportMethods(summary)
importClassesFrom(GOSemSim,GOSemSimDATA)
importClassesFrom(methods,data.frame)
importFrom(BiocParallel,MulticoreParam)
importFrom(BiocParallel,bplapply)
importFrom(BiocParallel,multicoreWorkers)
importFrom(GOSemSim,combineScores)
importFrom(GOSemSim,load_OrgDb)
importFrom(GOSemSim,termSim)
importFrom(fgsea,fgsea)
importFrom(ggplot2,aes)
importFrom(ggplot2,element_blank)
importFrom(ggplot2,element_text)
importFrom(ggplot2,facet_grid)
importFrom(ggplot2,geom_text)
importFrom(ggplot2,geom_tile)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,margin)
importFrom(ggplot2,scale_fill_gradient)
importFrom(ggplot2,scale_x_discrete)
importFrom(ggplot2,scale_y_discrete)
importFrom(ggplot2,theme)
importFrom(ggplot2,theme_bw)
importFrom(ggplot2,xlab)
importFrom(ggplot2,ylab)
importFrom(methods,is)
importFrom(methods,new)
importFrom(methods,show)
importFrom(qvalue,qvalue)
importFrom(reshape2,melt)
importFrom(stats,p.adjust)
importFrom(stats,phyper)
importFrom(stats,setNames)
importFrom(utils,head)
importFrom(utils,setTxtProgressBar)
importFrom(utils,str)
importFrom(utils,tail)
importFrom(utils,txtProgressBar)
importFrom(yulab.utils,yulab_msg)
importMethodsFrom(AnnotationDbi,columns)
importMethodsFrom(AnnotationDbi,exists)
importMethodsFrom(AnnotationDbi,get)
importMethodsFrom(AnnotationDbi,keys)
importMethodsFrom(AnnotationDbi,keytypes)
importMethodsFrom(AnnotationDbi,select)
importMethodsFrom(AnnotationDbi,toTable)
