# DOSE: Disease Ontology Semantic and Enrichment analysis

[![](https://img.shields.io/badge/release%20version-3.30.2-green.svg)](https://www.bioconductor.org/packages/DOSE)
[![](https://img.shields.io/badge/devel%20version-3.31.3-green.svg)](https://github.com/guangchuangyu/DOSE)
[![Bioc](http://www.bioconductor.org/shields/years-in-bioc/DOSE.svg)](https://www.bioconductor.org/packages/devel/bioc/html/DOSE.html#since)
[![codecov](https://codecov.io/gh/GuangchuangYu/DOSE/branch/master/graph/badge.svg)](https://codecov.io/gh/GuangchuangYu/DOSE/)

[![Project Status: Active - The project has reached a stable, usable
state and is being actively
developed.](http://www.repostatus.org/badges/latest/active.svg)](http://www.repostatus.org/#active)
[![platform](http://www.bioconductor.org/shields/availability/devel/DOSE.svg)](https://www.bioconductor.org/packages/devel/bioc/html/DOSE.html#archives)
[![Build
Status](http://www.bioconductor.org/shields/build/devel/bioc/DOSE.svg)](https://bioconductor.org/checkResults/devel/bioc-LATEST/DOSE/)
[![](https://img.shields.io/badge/download-836274/total-blue.svg)](https://bioconductor.org/packages/stats/bioc/DOSE)
[![](https://img.shields.io/badge/download-20017/month-blue.svg)](https://bioconductor.org/packages/stats/bioc/DOSE)

This package implements five methods proposed by Resnik, Schlicker,
Jiang, Lin and Wang respectively for measuring semantic similarities
among DO terms and gene products. Enrichment analyses including
hypergeometric model and gene set enrichment analysis are also
implemented for discovering disease associations of high-throughput
biological data.

## :writing_hand: Authors

Guangchuang YU <https://yulab-smu.top>

School of Basic Medical Sciences, Southern Medical University

Learn more at <https://yulab-smu.top/contribution-knowledge-mining/>.

Please cite the following article when using `DOSE`:

Guangchuang Yu, Li-Gen Wang, Guang-Rong Yan, Qing-Yu He. DOSE: an
R/Bioconductor package for Disease Ontology Semantic and Enrichment
analysis. Bioinformatics. 2015, 31(4):608-609.
