#' @keywords internal
"_PACKAGE"


#' Datasets
#'
#' Information content and DO term to entrez gene IDs mapping
#'
#'
#' @name DataSet
#' @aliases  geneList
#' NCG_EXTID2PATHID NCG_PATHID2EXTID NCG_PATHID2NAME
#' DGN_EXTID2PATHID DGN_PATHID2EXTID DGN_PATHID2NAME
#' VDGN_EXTID2PATHID VDGN_PATHID2EXTID VDGN_PATHID2NAME
#' @docType data
#' @keywords datasets
NULL
