---
title: "DOSE: Disease Ontology Semantic and Enrichment analysis"
author: 
- name: Guangchuang Yu
  email: guangchuangyu@gmail.com
  affiliation: Department of Bioinformatics, School of Basic Medical Sciences, Southern Medical University
date: "`r Sys.Date()`"
biblio-style: apalike
output:
  prettydoc::html_pretty:
    toc: true
    theme: cayman
    highlight: github
  pdf_document:
    toc: true
vignette: >
  %\VignetteIndexEntry{DOSE}
  %\VignettePackage{DOSE}
  % \VignetteEngine{knitr::rmarkdown}
  % \usepackage[utf8]{inputenc}
  %\VignetteEncoding{UTF-8}
---

```{r style, echo=FALSE, results="asis", message=FALSE}
knitr::opts_chunk$set(tidy = FALSE,
                      warning = FALSE,
                      message = FALSE)

Biocpkg <- function (pkg) {
    sprintf("[%s](http://bioconductor.org/packages/%s)", pkg, pkg)
}

```


```{r echo=FALSE, results='hide', message=FALSE}
library(DOSE)
```


# Vignette

Please go to <https://yulab-smu.top/biomedical-knowledge-mining-book/> for the full vignette.



# Citation

If you use `r Biocpkg("DOSE")` in published research, please cite G. Yu (2015).


__*G Yu*__, LG Wang, GR Yan, QY He. DOSE: an R/Bioconductor package for Disease Ontology Semantic and Enrichment analysis. __*Bioinformatics*__ 2015, 31(4):608-609. <http://dx.doi.org/10.1093/bioinformatics/btu684>.


# Need helps?


If you have questions/issues, please post
to [Bioconductor support site](https://support.bioconductor.org/) and tag your
post with *DOSE*.



