% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/doSim.R
\name{doseSim}
\alias{doseSim}
\alias{doSim}
\title{doseSim}
\usage{
doseSim(DOID1, DOID2, measure = "Wang", ont = "HDO")

doSim(DOID1, DOID2, measure = "Wang", ont = "HDO")
}
\arguments{
\item{DOID1}{DO term, MPO term or HPO term vector}

\item{DOID2}{DO term, MPO term or HPO term vector}

\item{measure}{one of "Wang", "Resnik", "Rel", "Jiang", "Lin", and "TCSS".}

\item{ont}{one of "HDO", "HPO" and "MPO"}
}
\value{
score matrix
}
\description{
measuring similarities between two DO term vectors.
}
\details{
provide two term vectors, this function will calculate their similarities.
}
\author{
Guangchuang Yu \url{https://yulab-smu.top}
}
