% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/accessor.R
\docType{methods}
\name{summary}
\alias{summary}
\title{summary method}
\usage{
summary(object, ...)

summary(object, ...)
}
\arguments{
\item{object}{A \code{enrichResult} instance.}

\item{...}{additional parameter}
}
\value{
A data frame

A data frame
}
\description{
summary method for \code{gseaResult} instance

summary method for \code{enrichResult} instance
}
\author{
Guangchuang Yu \url{https://guangchuangyu.github.io}

Guangchuang Yu \url{http://guangchuangyu.github.io}
}
