% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/simplot.R
\name{theme_dose}
\alias{theme_dose}
\title{theme_dose}
\usage{
theme_dose(font.size = 14)
}
\arguments{
\item{font.size}{font size}
}
\value{
ggplot theme
}
\description{
ggplot theme of DOSE
}
\examples{
library(ggplot2)
qplot(1:10) + theme_dose()
}
